Module decryption
brass_
aphid_
wire_
decryption
0.0.2
Module decryption
Module Items
Modules
Structs
Enums
In crate brass_
aphid_
wire_
decryption
brass_aphid_wire_decryption
Module
decryption
Modules

key_
manager
key_
space
s2n_
tls_
intercept
stream_
decrypter
tls_
stream
transcript
Structs

Decrypting
Pipe
This makes it easy to decrypt the traffic from a TLS implementation which operates over some generic type implementing Read + Write. E.g.
openssl::SslStream
Enums

Mode