KeyManager

Struct KeyManager 

pub struct KeyManager(/* private fields */);
The KeyManager holds all of the keys that are generated by the key logging callbacks. This has been primarily designed to work with s2n-tls’s key logging, but should work with other implementations as well.

The KeyManager is internally reference counter and can be safely shared across connections.

Notes that a single KeyManager is generally set on a config but decrypting is done per-connection, so that is a one-to-many relationship.

The Pin is necessary for safe use with s2n-tls, which will case the reference to a c_void pointer.

Implementations

Source

impl KeyManager

pub fn new() -> Self

pub fn enable_s2n_logging(&self, config: &mut Builder)

pub fn parse_key_log_line(&self, line: &[u8])

This signature is required by OpenSSL

pub fn register_key(&self, key: NssLog)

pub fn handshake_space( &self, mode: Mode, client_random: &[u8], cipher: Cipher, ) -> Option<KeySpace>

the key used for initial handshake messages in TLS 1.3

pub fn first_application_space( &self, mode: Mode, client_random: &[u8], cipher: Cipher, ) -> Option<KeySpace>

Retrieve the KeySpace for a particular application space.

Index will be 0 for the initial set of traffic keys, but higher indicies will be used in the event of key updates.