KeySpace

Struct KeySpace 

pub struct KeySpace {
    pub cipher: Cipher,
    pub secret: Vec<u8>,
    pub record_count: u64,
    pub key_epoch: Option<usize>,
}
KeySpace represents the decryption context of some keys.

E.g. Handshake Space or Traffic Space.

Fields

cipher: Ciphersecret: Vec<u8>record_count: u64key_epoch: Option<usize>

Defined for application traffic

Implementations

Source

impl KeySpace

pub fn handshake_traffic_secret(secret: Vec<u8>, cipher: Cipher) -> Self

Construct a new key space from a handshake secret

pub fn first_traffic_secret(secret: Vec<u8>, cipher: Cipher) -> Self

Construct a new key space from the first traffic secret

pub fn key_update(&self) -> Self

Construct a new key space following a key update

Defined in https://www.rfc-editor.org/rfc/rfc8446#section-7.2

pub fn traffic_key(&self) -> Result<(Vec<u8>, Vec<u8>)>

Return the actual key and IV which will be used the the symmetric cipher

pub fn decrypt_record( &mut self, header: &RecordHeader, record: &[u8], ) -> Vec<u8>

  • record: the encrypted record, exclusive of the header
  • sender: the party who transmitted the record