pub struct ConversationState {
pub client_random: Option<Vec<u8>>,
pub selected_protocol: Option<Protocol>,
pub selected_cipher: Option<Cipher>,
}Expand description
The conversation state tracks the context necessary to decrypt the connection.
For example, we need to know the cipher to know how to decrypt encrypted records.
Fields
client_random: Option<Vec<u8>>selected_protocol: Option<Protocol>selected_cipher: Option<Cipher>Trait Implementations
Sourceimpl Clone for ConversationState
impl Clone for ConversationState
Sourcefn clone(&self) -> ConversationState
fn clone(&self) -> ConversationState
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConversationState
impl Debug for ConversationState
Sourceimpl Default for ConversationState
impl Default for ConversationState
Sourcefn default() -> ConversationState
fn default() -> ConversationState
Returns the “default value” for a type. Read more