pub struct DecryptingPipe<T> {
pub pipe: T,
pub decrypter: StreamDecrypter,
pub identity: Option<Mode>,
}Expand description
This makes it easy to decrypt the traffic from a TLS implementation which operates
over some generic type implementing Read + Write. E.g. openssl::SslStream
Fields
pipe: Tdecrypter: StreamDecrypteridentity: Option<Mode>Implementations
Sourceimpl DecryptingPipe<ArchaicCPipe>
impl DecryptingPipe<ArchaicCPipe>
Sourcepub fn s2n_tls_decrypter(
key_manager: KeyManager,
connection: &mut Connection,
) -> Box<Self>
pub fn s2n_tls_decrypter( key_manager: KeyManager, connection: &mut Connection, ) -> Box<Self>
configure a decrypting pipe for an s2n-tls connection.
This will steal the currently configure send/recv callbacks and wrap them in a pipe that the decrypter will use to populate the data
Sourceimpl<T: Read + Write> DecryptingPipe<T>
impl<T: Read + Write> DecryptingPipe<T>
pub fn new(key_manager: KeyManager, pipe: T) -> Self
Sourcepub fn enable_s2n_tls_decryption(
decrypter: &Box<Self>,
connection: &mut Connection,
)
pub fn enable_s2n_tls_decryption( decrypter: &Box<Self>, connection: &mut Connection, )
Used to decrypt s2n-tls connections
First the underlying “real” connection IO stuff needs to be retrieved and
packaged into an ArchaicCPipe. At that point this can be used to set the
appropriate callbacks on s2n-tls.