Module transcript
brass_
aphid_
wire_
decryption
0.0.2
Module transcript
Module Items
Structs
Traits
In brass_
aphid_
wire_
decryption::
decryption
brass_aphid_wire_decryption
::
decryption
Module
transcript
Structs

Recording
Send
Handle
A handle that records data sent through it and forwards it to the original IO stream
Test
Pair
Transcript
Holds all of the writes that occurred during a TLS handshake
Transcript
Traits

Test
Pair
Extension