Transcript

Struct Transcript 

pub struct Transcript {
    pub record_transcript: Mutex<Vec<(Mode, usize)>>,
    pub content_transcript: Mutex<Vec<(Mode, ContentValue)>>,
}

Fields

record_transcript: Mutex<Vec<(Mode, usize)>>

a list of the record sizes sent by each peer

content_transcript: Mutex<Vec<(Mode, ContentValue)>>

a list of the content sent by each peer TODO: why are these mutexes? I think the vast majority of the time

Implementations

Source

impl Transcript

pub fn record_record(&self, sender: Mode, size: usize)

pub fn record_content(&self, sender: Mode, content: ContentValue)

pub fn records(&self) -> Vec<(Mode, usize)>

pub fn content(&self) -> Vec<(Mode, usize)>

pub fn client_hellos(&self) -> Vec<ClientHello>

pub fn client_hello(&self) -> ClientHello

panics if there is more than one (TLS 1.3 HRR)

pub fn server_hello(&self) -> ServerHello

pub fn hello_retry_request(&self) -> Option<HelloRetryRequest>