pub struct KeyManager(/* private fields */);Expand description
The KeyManager holds all of the keys that are generated by the key logging callbacks. This has been primarily designed to work with s2n-tls’s key logging, but should work with other implementations as well.
The KeyManager is internally reference counter and can be safely shared across connections.
Notes that a single KeyManager is generally set on a config but decrypting is done per-connection, so that is a one-to-many relationship.
The Pin is necessary for safe use with s2n-tls, which will case the reference
to a c_void pointer.
Implementations
Sourceimpl KeyManager
impl KeyManager
pub fn new() -> Self
pub fn enable_s2n_logging(&self, config: &mut Builder)
Sourcepub fn parse_key_log_line(&self, line: &[u8])
pub fn parse_key_log_line(&self, line: &[u8])
This signature is required by OpenSSL
pub fn register_key(&self, key: NssLog)