Module transcript

Module transcript 

Structs

RecordingSendHandle
A handle that records data sent through it and forwards it to the original IO stream
TestPairTranscript
Holds all of the writes that occurred during a TLS handshake
Transcript

Traits

TestPairExtension